==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/61/61ec30306f34387247ff9dc14cc20c23.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ReportBundle/Event/ColumnCollectEvent.php */
class __TwigTemplate_06ef0a6524c491050b4cbb9eede0c2d6 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\ReportBundle\\Event;

use Symfony\\Contracts\\EventDispatcher\\Event;

final class ColumnCollectEvent extends Event
{
    /**
     * @var array<string, mixed>
     */
    private array \$columns;

    /**
     * @param array<string, mixed> \$properties
     */
    public function __construct(
        private string \$object,
        private array \$properties = []
    ) {
        \$this->columns = [];
    }

    public function getObject(): string
    {
        return \$this->object;
    }

    /**
     * @return array<string, mixed>
     */
    public function getProperties(): array
    {
        return \$this->properties;
    }

    /**
     * @param array<string, array<string, mixed>> \$column
     */
    public function addColumns(array \$column): void
    {
        \$this->columns = array_merge(\$this->columns, \$column);
    }

    /**
     * @return array<string, array<string, mixed>>
     */
    public function getColumns(): array
    {
        return \$this->columns;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ReportBundle/Event/ColumnCollectEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ReportBundle/Event/ColumnCollectEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/ReportBundle/Event/ColumnCollectEvent.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/61/61ec30306f34387247ff9dc14cc20c23.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ReportBundle/Event/ColumnCollectEvent.php */
class __TwigTemplate_06ef0a6524c491050b4cbb9eede0c2d6 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\ReportBundle\\Event;

use Symfony\\Contracts\\EventDispatcher\\Event;

final class ColumnCollectEvent extends Event
{
    /**
     * @var array<string, mixed>
     */
    private array \$columns;

    /**
     * @param array<string, mixed> \$properties
     */
    public function __construct(
        private string \$object,
        private array \$properties = []
    ) {
        \$this->columns = [];
    }

    public function getObject(): string
    {
        return \$this->object;
    }

    /**
     * @return array<string, mixed>
     */
    public function getProperties(): array
    {
        return \$this->properties;
    }

    /**
     * @param array<string, array<string, mixed>> \$column
     */
    public function addColumns(array \$column): void
    {
        \$this->columns = array_merge(\$this->columns, \$column);
    }

    /**
     * @return array<string, array<string, mixed>>
     */
    public function getColumns(): array
    {
        return \$this->columns;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ReportBundle/Event/ColumnCollectEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ReportBundle/Event/ColumnCollectEvent.php", "/var/www/html/production-demo/app/bundles/ReportBundle/Event/ColumnCollectEvent.php");
    }
}
